** Mediation and moderation in Stata **

use nhanes, clear
codebook, compact

regress sbp age

regress sbp c.age##sex

margins sex, at(age=(20(10)60))

marginsplot

marginsplot, title("Sex moderates age effect on blood pressure") ///
ytitle("Systolic blood pressure (mm/Hg)") scheme(sj)

regress sbp c.age##race

testparm c.age#race

quietly margins race, at(age=(20(10)60))
marginsplot

regress sbp c.age##c.weight

summarize weight
quietly margins, at(age=(20(10)60) weight=56) at(age=(20(10)60) weight=72) ///
at(age=(20(10)60) weight=88)

marginsplot

marginsplot, title("Weight doesn't moderate age effect on blood pressure") ///
ytitle("Systolic blood pressure (mm/Hg)") ///
legend(order(1 "56kg" 2 "72kg" 3 "88kg") rows(1))

logit heartatk c.age##sex

logit heartatk c.age##sex, or 

quietly margins sex, at(age=(20(10)60))
marginsplot

sembuilder

sem (age -> cholesterol sbp) (cholesterol -> sbp)

estat teffects

sem (age -> sbp)

sem, coeflegend

bootstrap direct=(_b[sbp:age]) ///
indirect=(_b[cholesterol:age]*_b[sbp:cholesterol]) ///
total=(_b[sbp:age]+_b[cholesterol:age]*_b[sbp:cholesterol]), reps(1000) nodots: /// 
sem (age -> cholesterol sbp) (cholesterol -> sbp)

estat bootstrap, percentile

sem (age cholesterol weight -> sbp) (age -> cholesterol weight)

estat teffects

nlcom (cholesterol:_b[cholesterol:age]*_b[sbp:cholesterol]) ///
(weight:_b[weight:age]*_b[sbp:weight])

quietly bootstrap cholesterol=(_b[cholesterol:age]*_b[sbp:cholesterol]) ///
weight=(_b[weight:age]*_b[sbp:weight]), reps(1000) nodots: /// 
sem (age cholesterol weight -> sbp) (age -> cholesterol weight)
estat bootstrap, percentile

gen ageXsex = age*sex
sem (age sex ageXsex -> sbp)

sem (age -> sbp), group(sex)

sem (age -> sbp), group(sex) ginvariant(serrvar)

estat ginvariant

sem (age -> cholesterol sbp) (cholesterol -> sbp), group(sex)

estat teffects

sem, coeflegend

testnl (_b[cholesterol:0bn.sex#c.age]* _b[sbp:0bn.sex#c.cholesterol]) = ///
(_b[cholesterol:1.sex#c.age]* _b[sbp:1.sex#c.cholesterol])

estat ginvariant

gsem (age cholesterol -> heartatk, logit) (age -> cholesterol)

estat eform heartatk

nlcom indirect:_b[cholesterol:age]*_b[heartatk:cholesterol]

quietly bootstrap indirect=(_b[cholesterol:age]*_b[heartatk:cholesterol]), ///
reps(1000) nodots: gsem (age cholesterol -> heartatk, logit) (age -> cholesterol)
estat bootstrap, percentile
